<h1>Learning Curves</h1>

```python hl_lines="16 17"
{% include 'examples/advanced/learning_curves.py' %}
```

![PHOTONAI Learning Curve Plot](../assets/img/photonai/learning_curves.png "PHOTONAI learning curve plot")